@@ -4,7 +4,7 @@ import time
 import webbrowser
 from threading import Thread
 
-from git import Repo, InvalidGitRepositoryError
+from git import Repo, InvalidGitRepositoryError, GitCommandError
 from halo import Halo
 
 from starmart.config.config import Config
@@ -46,8 +46,7 @@ class Action(object):
 class InitAction(Action):
 
     def act(self):
-        cloned = self.__clone_default_code__()
-        self.__auth_with_web_browser__(cloned)
+        self.__auth_with_web_browser__()
 
     @Halo(text='Cloning starter code repo', spinner='dots')
     def __clone_default_code__(self):
@@ -58,13 +57,14 @@ class InitAction(Action):
                 break
         return cloned
 
-    def __auth_with_web_browser__(self, repo: Repo):
+    def __auth_with_web_browser__(self):
         webbrowser.open(f'{self.config.authentication_host()}/development/login')
 
         def callback(url):
             remote_host = self.config.git_remote_host()
             if not url.startswith(remote_host):
                 raise ValueError(f'URL does not match the authentication host: {remote_host}')
+            repo = self.__clone_default_code__()
             repo.create_remote('starmart', url=url)
             print('Happy coding!')
 
@@ -82,6 +82,7 @@ class DeployAction(Action):
 
     @Halo(text='Pushing latest commits', spinner='dots')
     def __configure_repo__(self):
+        repo = None
         try:
             repo = Repo('.')
             remote = None
@@ -92,10 +93,11 @@ class DeployAction(Action):
             if remote is None:
                 raise ValueError(f'The repository does not contain the starmart remote. Please call' +
                                  f' {bold("starmart init")}, before calling {bold("starmart deploy")}.')
-            remote.push()
-            print('Pushed. Happy coding!')
+            remote.push(refspec="main:main")
         except InvalidGitRepositoryError:
             raise ValueError('Github repository not initialized. Call starmart init before calling starmart deploy.')
+        finally:
+            print('\nPushed. Happy coding!')
 
 
 class CloneAction(Action):
@@ -109,9 +111,10 @@ class CloneAction(Action):
             raise ValueError(bold('starmart clone') + ' needs the project id')
         spinner = Halo(text=f'Cloning project {project_id}', spinner='dots')
         spinner.start()
-        repo = Repo.clone_from(f'{self.config.git_remote_host()}/{project_id}', f'starmart_project_{project_id}')
+        repo = Repo.clone_from(f'{self.config.git_remote_host()}/{project_id}.git', f'starmart_project_{project_id}')
         repo.remote('origin').rename('starmart')
         spinner.stop()
+        print('Cloned. Happy coding!')
 
 
 def exit_after_seconds(seconds=2):
